# Instabot

Free Instagram python bot, [private Instagram API wrapper](https://github.com/instagrambot/instabot/tree/master/instabot/api) and a [huge amount of ready-to-use automation scripts](https://github.com/instagrambot/instabot/tree/master/examples).

We are the most used Instagram library on GitHub (according to "Used by" counter). 🎉 Join our [Large Telegram community](https://t.me/instabotproject) for more Instagram tricks. 🚀

---
### [Read the Docs](https://instagrambot.github.io/docs/) | [Contribute](https://github.com/instagrambot/docs/blob/master/CONTRIBUTING.md)
---

[![Telegram Chat](https://img.shields.io/badge/chat%20on-Telegram-blue.svg)](https://t.me/instabotproject)
[![paypal](https://img.shields.io/badge/Donate-PayPal-green.svg)](https://paypal.me/okhlopkov/10)
![Python 2.7, 3.5, 3.6, 3.7](https://img.shields.io/badge/python-2.7%2C%203.5%2C%203.6%2C%203.7-blue.svg)
[![PyPI version](https://badge.fury.io/py/instabot.svg)](https://badge.fury.io/py/instabot)
[![Build Status](https://travis-ci.org/instagrambot/instabot.svg?branch=master)](https://travis-ci.org/instagrambot/instabot)
[![codecov](https://codecov.io/gh/instagrambot/instabot/branch/master/graph/badge.svg)](https://codecov.io/gh/instagrambot/instabot)

![the best python instagram scripts](https://raw.githubusercontent.com/instagrambot/docs/master/img/instabot_3_bots.png "Instabot is better than other open-source bots!")

### Installation
Install `instabot` with:
``` bash
pip install -U instabot
```
#### or see [this](https://instagrambot.github.io/docs/en/#installation) for more details.

### Quickstart

<img src="https://user-images.githubusercontent.com/5613295/62396780-b6441c80-b57c-11e9-89b0-931c159f0cab.png" width="400">

Instabot has a lot of predefined filters (like skipping very popular accounts because they will not notice you) which maximize the overall impact. But you can remove them if you like or even set your own parameters: (full list [here](https://github.com/instagrambot/instabot/blob/master/instabot/bot/bot.py#L86))

<img src="https://user-images.githubusercontent.com/5613295/62396777-b5ab8600-b57c-11e9-90a7-56b7294a9a6a.png" width="400">

If this library solved some of your problems, please consider buying [me](https://github.com/ohld) a coffee, sending some bucks to [PayPal](https://paypal.me/okhlopkov/10) or become our [patron](https://patreon.com/join/morejust). :wink:

<a href="https://www.buymeacoffee.com/okhlopkov" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/yellow_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>

*Use only for educational purposes. We don't provide any guarantee.*
